# Chromator: Color shades generator

[![Poetry](https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/githuib/chromator/master/assets/logo.json)](https://pypi.org/project/chromator)
[![PyPI - Version](https://img.shields.io/pypi/v/chromator)](https://pypi.org/project/chromator/#history)
[![PyPI - Python Versions](https://img.shields.io/pypi/pyversions/chromator)](https://pypi.org/project/chromator)

## Installation

```commandline
pip install chromator
```

## Usage

(placeholder)
